@@ -1,5 +1,6 @@
 from ....abstract_type_builder import AbstractTypeBuilder, CacheableTypeBuilder
 from graphene import InputObjectType, Enum
+from graphql import Undefined
 
 
 class SortDirection(Enum):
@@ -24,7 +25,7 @@ class OrderClause(CacheableTypeBuilder, AbstractTypeBuilder):
             field_name = field.name
             if field.many_to_one or field.one_to_one and field_name != "id":
                 field_name = "{}_id".format(field_name)
-            order_by_type_attrs[field_name] = SortDirection()
+            order_by_type_attrs[field_name] = SortDirection(default_value=Undefined)
 
         return type(
             "OrderBy{}".format(model_class.__name__),
