@@ -10,7 +10,7 @@ def visit_query(registry, info):
             ReadPermissionsCheckVisitor(registry, info),
         ]
     )
-    visit(info.field_asts[0], query_visitor)
+    visit(info.field_nodes[0], query_visitor)
     return query_visitor.artifacts
 
 
